{{ fullname }}
{{ underline }}

.. currentmodule:: {{ module }}

.. autoclass:: {{ objname }}
   :members:

..
  This file can be used instead of my_autosummary_class.rst
  when RTD build timeouts occur (since it's faster).  This
  template puts the member-function descriptions (docstrings,
  etc) for a class all in the *same* page, as opposed to
  creating stub pages for each function (as my_autosummary_class.rst
  does).
